---
hide:
    - toc
---
# 🇳🇴 Norwegian

See the [leaderboard page](/leaderboards) for more information about all the columns.

To see only generative models, you can search for "few-shot" or "zero-shot" in the
search bar below

<iframe
    title="🇳🇴 Norwegian Language Model Leaderboard"
    aria-label="Table" id="datawrapper-chart-RXjjq"
    src="https://datawrapper.dwcdn.net/THj74/"
    scrolling="no"
    frameborder="0"
    style="width: 0; min-width: 100% !important; border: none;"
    height="1461"
    data-external="1"
/>
<script type="text/javascript">
    !function(){
        "use strict";
        window.addEventListener(
            "message",
            function(a){
                if (void 0 !== a.data["datawrapper-height"]){
                    var e = document.querySelectorAll("iframe");
                    for (var t in a.data["datawrapper-height"]){
                        for (var r=0; r<e.length; r++){
                            if (e[r].contentWindow === a.source){
                                var i = a.data["datawrapper-height"][t]+"px";
                                e[r].style.height = i
                            }
                        }
                    }
                }
            }
        )
    }();
</script>
